<?php

namespace Drupal\jwt_token_test\Controller;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Controller\ControllerBase;
use Jose\Component\KeyManagement\JWKFactory;
use Symfony\Component\HttpFoundation\Request;
use Jose\Easy\Load;

/**
 * Class JWTTokenController.
 *
 * @package Drupal\jwt_token_test\Controller
 */
class JWTTokenController extends ControllerBase {

  /**
   * Test endpoint.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return array
   */
  public function testJWEEndpoint(Request $request) {
    $token = $request->request->get('token');
    if (empty($token)) {
      return ['#markup' => 'Error: Empty token'];
    }

    $key = \Drupal::configFactory()->get('key.key.test_key');
    $jwk = JWKFactory::createFromKey($key->get('key_provider_settings.key_value'));
    if (!$jwk) {
      return ['#markup' => 'Error: Could not load the key'];
    }

    $jwt = Load::jwe($token)
      ->algs(['RSA-OAEP-256'])
      ->encs(['A256CBC-HS512'])
      ->exp()
      ->iat(1000)
      ->nbf()
      ->key($jwk)
      ->run()
    ;

    return [
      '#markup' => $this->t('Logged in with payload: ') . Json::encode($jwt->claims->all()),
    ];

  }

}
